#!/bin/bash -l

cat << EOF
include:
  - "ci/global_variables.yml"
  - "ci/common.yml"
  - "ci/build.yml"
  - "ci/test.yml"
  - "ci/benchmark.yml"
  - "ci/postprocessing.yml"

stages:
  - build
  - test
  - benchmark
  - postprocessing
  - final

EOF

if [ -z "${HOSTLIST}" ];
then
  HOSTLIST=$(sinfo -t idle -h --partition=work -o "%n")
fi
if [ -z "${BENCHMARKS}" ];
then
  BENCHMARKS="mesa_pd uniformgridcpu phasefieldallencahn"
fi
if [ -z "${GPU_BENCHMARKS}" ];
then
  GPU_BENCHMARKS="uniformgridgpu phasefieldallencahngpu"
fi

# Hard coded knowledge on the testcluster
HAS_GPU='medusa milan1'
NOT_TO_USE='broadep2 aurora1 warmup phinally interlagos1 ivyep1 rome2 icx36 applem1studio'

for HOST in ${HOSTLIST}; do
  if [[ $NOT_TO_USE == *"$HOST"* ]]; then
       continue
  fi
  cat << EOF
build-$HOST:
  extends: .build
  variables:
    SLURM_NODELIST: $HOST
EOF
  if [[ $HAS_GPU == *"$HOST"* ]]; then
  cat << EOF
    WALBERLA_BUILD_WITH_CUDA: "ON"
EOF
  fi
cat << EOF
test-$HOST:
  extends:
    - .test
  dependencies:
    - build-$HOST
  needs:
    - job: build-$HOST
  variables:
    SLURM_NODELIST: $HOST
EOF
  if [[ $HAS_GPU == *"$HOST"* ]]; then
  cat << EOF
    WALBERLA_BUILD_WITH_CUDA: "ON"
EOF
  fi
  CORES=$(sinfo -n $HOST -h -o "%c")
  for BENCHMARK in ${BENCHMARKS}; do
    if [ "$BENCHMARK" = "mesa_pd" ]; then
      TASKS=8
    else
      TASKS=$CORES
    fi
  cat << EOF

benchmark_${BENCHMARK}_${HOST}:
  extends:
    - .${BENCHMARK}_benchmark
  dependencies:
    - build-$HOST
  needs:
    - job: build-$HOST
    - job: test-$HOST
  variables:
    SLURM_NODELIST: $HOST
    SLURM_NTASKS_PER_NODE: $TASKS

upload_${BENCHMARK}_${HOST}:
  extends:
    - .upload_${BENCHMARK}
  needs:
    - job: benchmark_${BENCHMARK}_${HOST}
  variables:
    HOST: $HOST

EOF
  done
  if [[ $HAS_GPU == *"$HOST"* ]]; then
  for BENCHMARK in ${GPU_BENCHMARKS}; do

  cat << EOF
benchmark_${BENCHMARK}_${HOST}:
  extends:
    - .${BENCHMARK}_benchmark
  dependencies:
    - build-$HOST
  needs:
    - job: build-$HOST
    - job: test-$HOST
  variables:
    SLURM_NODELIST: $HOST

upload_${BENCHMARK}_${HOST}:
  extends:
    - .upload_${BENCHMARK}
  needs:
    - job: benchmark_${BENCHMARK}_${HOST}
  variables:
    HOST: $HOST

EOF
  done
  fi
done
cat << EOF
upload_pipeline_stats:
  stage: final
  tags:
    - testcluster
  variables:
    NO_SLURM_SUBMIT: 1
  when:
    always
  script:
    - !reference [.load_cbutil, before_script]
    - pip uninstall -y cb-util
    - !reference [.load_cbutil, after_script]
EOF
